#
# spec file for package pam_wrapper
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


############################# NOTE ##################################
#
# This is a special library. You are not able to link this library.
# Do NOT create library package or a devel package!
#
############################# NOTE ##################################
%bcond_without python2
Name:           pam_wrapper
Version:        1.1.4
Release:        2.4
Summary:        A tool to test PAM applications and PAM modules
License:        GPL-3.0-or-later
URL:            https://cwrap.org/
Source0:        https://ftp.samba.org/pub/cwrap/%{name}-%{version}.tar.gz
Source1:        https://ftp.samba.org/pub/cwrap/%{name}-%{version}.tar.gz.asc
Source2:        %{name}-rpmlintrc
Patch0:         pam_wrapper-fix-cmocka-1.1.6+-support.patch
BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  libcmocka-devel
BuildRequires:  pam-devel
BuildRequires:  pkgconfig
BuildRequires:  python-rpm-macros
BuildRequires:  pkgconfig(python3)
Recommends:     cmake
Recommends:     pkgconfig
%if %{with python2}
BuildRequires:  pkgconfig(python2)
%endif

%description
This component of cwrap allows you to either test your PAM (Linux-PAM
and OpenPAM) application or module.

For testing PAM applications, a simple PAM module called pam_matrix is
included. If you plan to test a PAM module, you can use the pamtest library,
which simplifies testing of modules. You can combine it with the cmocka
unit testing framework, or you can use the provided Python bindings to
write tests for your module in Python.

This package does not have a devel package, because this project is for
development/testing.

%package -n libpamtest0
Summary:        A tool to test PAM applications and PAM modules
Requires:       pam_wrapper = %{version}-%{release}

%description -n libpamtest0
If you plan to test a PAM module, you can use this library, which simplifies
testing of modules.

%package -n libpamtest-devel
Summary:        A tool to test PAM applications and PAM modules
Requires:       libpamtest0 = %{version}-%{release}
Requires:       pam_wrapper = %{version}-%{release}
Recommends:     cmake
Recommends:     pkgconfig

%description -n libpamtest-devel
If you plan to develop tests for a PAM module, you can use this library,
which simplifies testing of modules. This subpackage includes the header
files for libpamtest

%package -n libpamtest-devel-doc
Summary:        The libpamtest API documentation

%description -n libpamtest-devel-doc
Documentation for libpamtest development.

%package -n python2-libpamtest
Summary:        A python wrapper for libpamtest
Requires:       libpamtest0 = %{version}-%{release}
Requires:       pam_wrapper = %{version}-%{release}

%description -n python2-libpamtest
If you plan to develop python tests for a PAM module, you can use this
library, which simplifies testing of modules. This subpackage includes
the header files for libpamtest

%package -n python3-libpamtest
Summary:        A python wrapper for libpamtest
Requires:       libpamtest0 = %{version}-%{release}
Requires:       pam_wrapper = %{version}-%{release}

%description -n python3-libpamtest
If you plan to develop python tests for a PAM module, you can use this
library, which simplifies testing of modules. This subpackage includes
the header files for libpamtest

%prep
%autosetup -p1

%build
# CMAKE_SKIP_RPATH:BOOL=OFF is required to run the tests!
%cmake \
  -DUNIT_TESTING=ON \
  -DCMAKE_SKIP_RPATH:BOOL=OFF
%cmake_build
%cmake_build doc

%install
%cmake_install

%if %{without python2}
rm -rf %{python2_sitearch}/pypamtest.so
%endif

%check
%ctest

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig
%post -n libpamtest0 -p /sbin/ldconfig
%postun -n libpamtest0 -p /sbin/ldconfig

%files
%doc AUTHORS README.md CHANGELOG
%license LICENSE
%{_libdir}/libpam_wrapper.so*
%{_libdir}/pkgconfig/pam_wrapper.pc
%dir %{_libdir}/cmake/pam_wrapper
%{_libdir}/cmake/pam_wrapper/pam_wrapper-config-version.cmake
%{_libdir}/cmake/pam_wrapper/pam_wrapper-config.cmake
%dir %{_libdir}/pam_wrapper
%{_libdir}/pam_wrapper/pam_matrix.so
%{_libdir}/pam_wrapper/pam_chatty.so
%{_libdir}/pam_wrapper/pam_get_items.so
%{_libdir}/pam_wrapper/pam_set_items.so
%{_mandir}/man1/pam_wrapper.1%{?ext_man}
%{_mandir}/man8/pam_chatty.8%{?ext_man}
%{_mandir}/man8/pam_matrix.8%{?ext_man}
%{_mandir}/man8/pam_get_items.8%{?ext_man}
%{_mandir}/man8/pam_set_items.8%{?ext_man}

%files -n libpamtest0
%{_libdir}/libpamtest.so.*

%files -n libpamtest-devel
%{_libdir}/libpamtest.so
%{_libdir}/pkgconfig/libpamtest.pc
%dir %{_libdir}/cmake/pamtest
%{_libdir}/cmake/pamtest/pamtest-config-version.cmake
%{_libdir}/cmake/pamtest/pamtest-config-relwithdebinfo.cmake
%{_libdir}/cmake/pamtest/pamtest-config.cmake
%{_includedir}/libpamtest.h

%files -n libpamtest-devel-doc
%doc build/doc/html

%if %{with python2}
%files -n python2-libpamtest
%{python2_sitearch}/pypamtest.so
%endif

%files -n python3-libpamtest
%{python3_sitearch}/pypamtest.so

%changelog
* Mon Feb 27 2023 Andreas Schneider <asn@cryptomilk.org>
- Fix building with cmocka >= 1.1.6
  * Added pam_wrapper-fix-cmocka-1.1.6+-support.patch
* Thu Oct 28 2021 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.1.4
  * https://gitlab.com/cwrap/pam_wrapper/-/blob/pam_wrapper-1.1.4/CHANGELOG
* Wed May 20 2020 Andreas Schneider <asn@cryptomilk.org>
- Fix the build (remove py2 lib if built without py2 support)
* Thu Mar 26 2020 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.1.3
  * https://gitlab.com/cwrap/pam_wrapper/-/blob/master/CHANGELOG
* Tue Mar 24 2020 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.1.2
  * https://gitlab.com/cwrap/pam_wrapper/-/blob/master/CHANGELOG
* Tue Mar 24 2020 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.1.1
  * https://gitlab.com/cwrap/pam_wrapper/-/blob/master/CHANGELOG
* Fri Mar 20 2020 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.1.0
  * Added support for pam_start_confdir()
  * Added pam_chatty module
  * Added gitlab CI support
  * Fixed crash when a PAM module outputs too much data
- Removed pam_wrapper-1.0.8-fix_with_latest_pam.patch
- Removed fix-pam-module-output-crash.patch
* Thu Mar 19 2020 Tomáš Chvátal <tchvatal@suse.com>
- Add patch to fix crash when testing fprintd:
  * fix-pam-module-output-crash.patch
- Fix build without python2 that is atm being removed from Tumbleweed
- Use cmake macros for build
* Mon Dec  9 2019 Andreas Schneider <asn@cryptomilk.org>
- Fix pam_wrapper with Linux-PAM master
- Added pam_wrapper-1.0.8-fix_with_latest_pam.patch
* Tue Jul 16 2019 Andreas Schneider <asn@cryptomilk.org>
- Build documentation in the build stage
- Use ctest macro
* Wed Sep 26 2018 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.0.7
  * Added support for running with AddressSanitizer
  * Added logging for pam_set_items module
  * Fixed building python modules
  * Fixed pam conversation in libpamtest
* Thu Feb 22 2018 asn@cryptomilk.org
- Update to version 1.0.5
  * Added support to build python2 and python3 module at the same time
  * Improved pam test directory creating
  * Fixed python 2.6 compatibilty
  * Fixed some build issues on FreeBSD
  * Fix build on OpenBSD
  * Fix a resource leak
- Removed pam_wrapper-1.0.3-build-python2-and-python3-modules.patch
* Mon Feb 12 2018 asn@cryptomilk.org
- Build python2 and python3 packages
- Added pam_wrapper-1.0.3-build-python2-and-python3-modules.patch
* Sun Feb  4 2018 asn@cryptomilk.org
- Add missing build require to python-rpm-macros
* Fri Apr  7 2017 asn@cryptomilk.org
- Update to version 1.0.3
  * Fixed some build issues with strict compiler flags
  * Logging to syslog is disabled by default
* Tue May 31 2016 asn@cryptomilk.org
- Update to version 1.0.2
  * Fixed pam_wrapper on some BSDs
  * Fixed simple conversation in libpamtest
* Sun Feb 14 2016 jengelh@inai.de
- Editorial fixes to the descriptions
* Mon Jan 18 2016 asn@cryptomilk.org
- Update to version 1.0.1
  * Fixed issue with audit_open() and sshd
  * Fixed several issues found by Coverity
  * Fixed python linking issues
* Thu Jan 14 2016 asn@cryptomilk.org
- Initial package
